Enum Position
pub enum Position {
Default,
Centered,
Specific(Point),
SpecificWith(fn(Size, Size) -> Point),
}Expand description
The position of a window in a given screen.
Variants
Default
The platform-specific default position for a new window.
Centered
The window is completely centered on the screen.
Specific(Point)
The window is positioned with specific coordinates: (X, Y).
When the decorations of the window are enabled, Windows 10 will add some
invisible padding to the window. This padding gets included in the
position. So if you have decorations enabled and want the window to be
at (0, 0) you would have to set the position to
(PADDING_X, PADDING_Y).
SpecificWith(fn(Size, Size) -> Point)
Like Specific, but the window is positioned with the specific coordinates returned by the function.
The function receives the window size and the monitor’s resolution as input.